#[non_exhaustive]pub enum DoorTransition {
None,
FinishedOpening,
FinishedOpen,
FinishedClosing,
}Expand description
Transition emitted when the door state changes phase.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No phase change occurred this tick.
FinishedOpening
Doors just finished opening and are now fully open.
FinishedOpen
Doors just finished holding open and are about to close.
FinishedClosing
Doors just finished closing and are now fully closed.