Module error

Module error 

Simulation error types. Error types for configuration validation and runtime failures.

Structs

RejectionContext
Additional context for a rider rejection.

Enums

RejectionReason
Reason a rider was rejected from boarding an elevator.
SimError
Errors that can occur during simulation setup or operation.