Module stop

Module stop 

Stop configuration helpers. Stop identifiers and configuration.

Structs

StopConfig
A stop at an arbitrary position along the elevator shaft.
StopId
Numeric identifier for a stop along the shaft.

Enums

StopRef
A reference to a stop by either its config-time StopId or its runtime EntityId.