pub struct NearestIdle;Expand description
No-op strategy: idle elevators stay where they stopped.
Use this to disable repositioning for a group while keeping the repositioning phase active for other groups.